@@ -76,9 +76,9 @@ new S3ToSqs(this, "S3ToSQSPattern", new S3ToSqsProps.Builder()
 |deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user provided props to override the default props for the dead letter SQS queue.|
 |deployDeadLetterQueue?|`boolean`|Whether to create a secondary queue to be used as a dead letter queue. Defaults to true.|
 |maxReceiveCount?|`number`|The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to 15.|
-|enableEncryptionWithCustomerManagedKey?|`boolean`|Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct.|
-|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|Optional imported encryption key to encrypt the SQS queue.|
-|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.KeyProps.html)|Optional user provided properties to override the default properties for the KMS encryption key.|
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SQS Queue with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.|
 |loggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Logging Bucket.|
 |logS3AccessLogs?| boolean|Whether to turn on Access Logging for the S3 bucket. Creates an S3 bucket with associated storage costs for the logs. Enabling Access Logging is a best practice. default - true|
 
@@ -178,9 +178,9 @@ class S3ToSqs(
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
-        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
-        :param encryption_key: Optional imported encryption key to encrypt the SQS queue. Default: - not specified.
-        :param encryption_key_props: Optional user provided props to override the default props for the encryption key. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, Providing both this and queueProps will cause an error. Default: - Default props are used
         :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
@@ -311,9 +311,9 @@ class S3ToSqsProps:
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
-        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
-        :param encryption_key: Optional imported encryption key to encrypt the SQS queue. Default: - not specified.
-        :param encryption_key_props: Optional user provided props to override the default props for the encryption key. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, Providing both this and queueProps will cause an error. Default: - Default props are used
         :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
@@ -430,30 +430,29 @@ class S3ToSqsProps:
     def enable_encryption_with_customer_managed_key(
         self,
     ) -> typing.Optional[builtins.bool]:
-        '''Use a KMS Key, either managed by this CDK app, or imported.
+        '''If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key.
 
-        If importing an encryption key, it must be specified in
-        the encryptionKey property for this construct.
+        This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.
 
-        :default: - true (encryption enabled, managed by this CDK app).
+        :default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
         '''
         result = self._values.get("enable_encryption_with_customer_managed_key")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
-        '''Optional imported encryption key to encrypt the SQS queue.
+        '''An optional, imported encryption key to encrypt the SQS Queue with.
 
-        :default: - not specified.
+        :default: - None
         '''
         result = self._values.get("encryption_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
 
     @builtins.property
     def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
-        '''Optional user provided props to override the default props for the encryption key.
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with.
 
-        :default: - Default props are used.
+        :default: - None
         '''
         result = self._values.get("encryption_key_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
